@@ -10,9 +10,15 @@
 SYS_FUNC(fstatfs64)
 {
 	if (entering(tcp)) {
+		/* fd */
 		printfd(tcp, tcp->u_arg[0]);
-		tprintf(", %" PRI_klu ", ", tcp->u_arg[1]);
+		tprint_arg_next();
+
+		/* size */
+		PRINT_VAL_U(tcp->u_arg[1]);
+		tprint_arg_next();
 	} else {
+		/* buf */
 		print_struct_statfs64(tcp, tcp->u_arg[2], tcp->u_arg[1]);
 	}
 	return 0;
