@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2017-2021 The strace developers.
+ * Copyright (c) 2017-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -76,6 +76,7 @@ enum decode_fd_bits {
 	DECODE_FD_SOCKET,
 	DECODE_FD_DEV,
 	DECODE_FD_PIDFD,
+	DECODE_FD_SIGNALFD,
 
 	NUM_DECODE_FD_BITS
 };
@@ -98,5 +99,6 @@ extern struct number_set *quiet_set;
 extern struct number_set *decode_fd_set;
 extern struct number_set *decode_pid_set;
 extern struct number_set *trace_set;
+extern struct number_set *trace_fd_set;
 
 #endif /* !STRACE_NUMBER_SET_H */
