@@ -21,9 +21,11 @@ decode_struct_stat(struct tcb *const tcp, const kernel_ulong_t addr)
 SYS_FUNC(stat)
 {
 	if (entering(tcp)) {
+		/* pathname */
 		printpath(tcp, tcp->u_arg[0]);
-		tprints(", ");
+		tprint_arg_next();
 	} else {
+		/* statbuf */
 		decode_struct_stat(tcp, tcp->u_arg[1]);
 	}
 	return 0;
@@ -32,9 +34,11 @@ SYS_FUNC(stat)
 SYS_FUNC(fstat)
 {
 	if (entering(tcp)) {
+		/* fd */
 		printfd(tcp, tcp->u_arg[0]);
-		tprints(", ");
+		tprint_arg_next();
 	} else {
+		/* statbuf */
 		decode_struct_stat(tcp, tcp->u_arg[1]);
 	}
 	return 0;
@@ -43,13 +47,19 @@ SYS_FUNC(fstat)
 SYS_FUNC(newfstatat)
 {
 	if (entering(tcp)) {
+		/* dirfd */
 		print_dirfd(tcp, tcp->u_arg[0]);
-		tprints(", ");
+		tprint_arg_next();
+
+		/* pathname */
 		printpath(tcp, tcp->u_arg[1]);
-		tprints(", ");
+		tprint_arg_next();
 	} else {
+		/* statbuf */
 		decode_struct_stat(tcp, tcp->u_arg[2]);
-		tprints(", ");
+		tprint_arg_next();
+
+		/* flags */
 		printflags(at_flags, tcp->u_arg[3], "AT_???");
 	}
 	return 0;
