@@ -10,8 +10,11 @@
 
 SYS_FUNC(umount2)
 {
+	/* target */
 	printpath(tcp, tcp->u_arg[0]);
-	tprints(", ");
+	tprint_arg_next();
+
+	/* flags */
 	printflags(umount_flags, tcp->u_arg[1], "MNT_???");
 
 	return RVAL_DECODED;
