@@ -2,7 +2,7 @@
  * Check verbose decoding of perf_event_open syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2022 The strace developers.
+ * Copyright (c) 2016-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -139,7 +139,7 @@ print_event_attr(struct perf_event_attr *attr_ptr, size_t size,
 	enum {
 		STRACE_PEA_ABBREV_SIZE =
 			offsetof(struct perf_event_attr, wakeup_events),
-		STRACE_PEA_SIZE = 128,
+		STRACE_PEA_SIZE = 136,
 	};
 
 	uint32_t read_size;
@@ -385,6 +385,14 @@ print_event_attr(struct perf_event_attr *attr_ptr, size_t size,
 	val = attr->sig_data;
 	printf(", sig_data=%#" PRIx64, (uint64_t) val);
 
+	if (size <= 128) {
+		cutoff = 128;
+		goto end;
+	}
+
+	val = attr->config3;
+	printf(", config3=%#" PRIx64, (uint64_t) val);
+
 	cutoff = STRACE_PEA_SIZE;
 
 end:
